@@ -1409,3 +1409,59 @@ def test_imports_from_cwd(tmpdir):
     with tmpdir.as_cwd():
         out = sass.compile(filename=main_scss.strpath)
         assert out == ''
+
+
+def test_import_no_css(tmpdir):
+    tmpdir.join('other.css').write('body {color: green}')
+    main_scss = tmpdir.join('main.scss')
+    main_scss.write("@import 'other';")
+    with pytest.raises(sass.CompileError):
+        sass.compile(filename=main_scss.strpath)
+
+
+@pytest.mark.parametrize('exts', [
+    ('.css',),
+    ['.css'],
+    ['.foobar', '.css'],
+])
+def test_import_css(exts, tmpdir):
+    tmpdir.join('other.css').write('body {color: green}')
+    main_scss = tmpdir.join('main.scss')
+    main_scss.write("@import 'other';")
+    out = sass.compile(
+        filename=main_scss.strpath,
+        custom_import_extensions=exts,
+    )
+    assert out == 'body {\n  color: green; }\n'
+
+
+def test_import_css_error(tmpdir):
+    tmpdir.join('other.css').write('body {color: green}')
+    main_scss = tmpdir.join('main.scss')
+    main_scss.write("@import 'other';")
+    with pytest.raises(TypeError):
+        sass.compile(
+            filename=main_scss.strpath,
+            custom_import_extensions='.css',
+        )
+
+
+def test_import_css_string(tmpdir):
+    tmpdir.join('other.css').write('body {color: green}')
+    with tmpdir.as_cwd():
+        out = sass.compile(
+            string="@import 'other';",
+            custom_import_extensions=['.css'],
+        )
+    assert out == 'body {\n  color: green; }\n'
+
+
+def test_import_ext_other(tmpdir):
+    tmpdir.join('other.foobar').write('body {color: green}')
+    main_scss = tmpdir.join('main.scss')
+    main_scss.write("@import 'other';")
+    out = sass.compile(
+        filename=main_scss.strpath,
+        custom_import_extensions=['.foobar'],
+    )
+    assert out == 'body {\n  color: green; }\n'
